# Dummy Script Compiler
#
# Purpose:
#	 Takes a game.ini file & creates dummy compiled scripts (.sco files) for each script file
#	 (in a given range).  The purpose of which is to avoid problems with initial compiling of 
#	 scripts that are dependent upon one another (via 'use' statements)
#
# Preparation:  
#   1)  Download the "SCI Script Compiler 1.33" by Brian Provinciano - should consist of:
#            keys.sch
#            readme.txt
#            scc.exe
#            scc.sch
#   2)  Copy the following files to the same directory as scc (should be available from the template game):
#            vocab.000
#            sci.sh
#            keys.sh
#            ... and finally YOUR game.ini file, containing references to all your script files
#
#   3)  Check/modify the variable values for $resourceMin and $resourceMax - this is the range of 
#       resource numbers that this script will create .sco files for.  For me, all my procedural
#       scripts have a resource # range from 300-799
#
#   4)  Run this script
#
#   5)  Copy the resulting .sco files from the working directory (work)
#
# Usage:    perl dummyScriptCompiler.pl 
#
# To Do:    Parameterize the min/max resource numbers
#           Parameterize the working directory
#           Add destination directory for .sco files, instead of having to copy them manually to a 'src' dir
#           Suppress the output of scc
#
# Do whatever you want with this file, except remove my name.
# Jeremiah Nellis, nellisjp@hotmail.com
# Version 1.0 - Jan 7th 2012

use strict;
use warnings;

my $gameiniFile = "game.ini";
my $workingDir = "./work/";

my $resourceMin = 300;     # lowest resource number to use
my $resourceMax = 799;     # highest resource number to use

my $line;
my $scriptNum;
my $scriptName;
my $i;

# Prerequisite checking

unless (-e 'scc.exe') {
 print "scc.exe (and all dependent files) need to be in the current directory!\n";
 exit;
}

unless (-e 'vocab.000') {
 print "vocab.000 needs to be in the current directory!\n";
 exit;
} 
 
unless (-e 'game.ini') {
 print "game.ini needs to be in the current directory!\n";
 exit;
} 

unless (-e 'sci.sh') {
 print "sci.sh needs to be in the current directory!\n";
 exit;
}

unless (-e 'keys.sh') {
 print "keys.sh needs to be in the current directory!\n";
 exit;
} 

# Make the working dir if it doesn't exist
unless (-e $workingDir) {
   mkdir($workingDir) or die "Can't create working directory!\n";
}

open(GAMEINI, $gameiniFile) or die("Could not open game.ini file.");
foreach $line (<GAMEINI>) {
   chomp($line);  # remove the newline from $line.
   ($scriptNum, $scriptName) = split /\=/, $line, 2;
   if (defined $scriptNum && defined $scriptName && $scriptNum =~ m/[0-9]/ ) {
       if (substr($scriptNum, 1) >= $resourceMin && substr($scriptNum,1) <= $resourceMax ) {

		  # Create the dummy script file
		  open WRITECODE, ">" . $workingDir . $scriptName . ".sc" or die $!;
		  print WRITECODE '(include "sci.sh")' . "\n";
		  print WRITECODE "(script " . substr($scriptNum,1) . ")\n";
		  print WRITECODE "(procedure public (" . $scriptName . "))";
	      close WRITECODE;
		  
		  # Compile it with scc
		  my $fullFileName = $workingDir . $scriptName . ".sc";
		  system("scc.exe " . $fullFileName);
		  
		  # Delete the dummy script file
		  unlink("script." . substr($scriptNum,1));
		  
		  # Delete dummy script file
		  unlink($fullFileName);
	   }
   }
}

# remove generated vocab.996
unlink("vocab.996");